@@ -84,13 +84,13 @@ impl<'a, Aux> Vm<'a, Aux> {
 
     /// Register a native function for use by Cao-Lang programs
     ///
-    pub fn register_function<'b, S, C>(&mut self, name: S, f: C)
+    pub fn register_function<S, C>(&mut self, name: S, f: C)
     where
-        S: Into<&'b str>,
+        S: Into<String>,
         C: VmFunction<Aux> + 'static,
     {
         let name = name.into();
-        let key = Handle::from_str(name).unwrap();
+        let key = Handle::from_str(name.as_str()).unwrap();
         self.callables
             .insert(key, Procedure::new(name, f))
             .expect("failed to insert new function");
@@ -221,9 +221,7 @@ impl<'a, Aux> Vm<'a, Aux> {
                         .map_err(|err| payload_to_error(err, instr_ptr))?;
                 }
                 Instruction::SetProperty => {
-                    let value = self.stack_pop();
-                    let key = self.stack_pop();
-                    let instance = self.stack_pop();
+                    let [value, key, instance] = self.runtime_data.stack.pop_n::<3>();
                     let table = self
                         .get_table_mut(instance)
                         .map_err(|err| payload_to_error(err, instr_ptr))?;
